<!--
SPDX-FileCopyrightText: 2021 - 2023 Mewbot Developers <mewbot@quicksilver.london>

SPDX-License-Identifier: CC-BY-4.0
-->

# mewbot-io-rss

[![Contributor Covenant](https://img.shields.io/badge/Contributor%20Covenant-2.1-4baaaa.svg)](CODE_OF_CONDUCT.md)

<!-- ALL-CONTRIBUTORS-BADGE:START - Do not remove or modify this section -->
[![All Contributors](https://img.shields.io/badge/all_contributors-2-orange.svg?style=flat-square)](CONTRIBUTORS.md)
<!-- ALL-CONTRIBUTORS-BADGE:END -->

[![Linting](https://github.com/mewbotorg/mewbot-io-rss/actions/workflows/review.yaml/badge.svg)](https://github.com/mewbotorg/mewbot-io-rss/actions/workflows/review.yaml)

[![PyPI version](https://img.shields.io/pypi/v/mewbot-io-rss.svg)](https://pypi.org/project/mewbot-io-rss)

[![Python versions](https://img.shields.io/pypi/pyversions/mewbot-io-rss.svg)](https://pypi.org/project/mewbot-io-rss)


[Mewbot](https://github.com/mewbotorg/mewbot) bindings for an io protocol!

A plugin which lets mewbot consume RSS feeds.

----

This [Mewbot](https://github.com/mewbotorg/mewbot) io plugin was generated with [Cookiecutter](https://github.com/audreyr/cookiecutter) along with [@ajcameron](https://github.com/ajcameron)'s [template-mewbot-plugin](https://github.com/mewbotorg/template-mewbot-plugin) cookiecutter template.

If you have any issues with the plugin please [file an issue for it!](https://github.com/mewbotorg/mewbot-io-rss/issues)

If you have any issues, or suggestions, for the template please [file an issue for it's template!](https://github.com/mewbotorg/template-mewbot-plugin/issues)


# Features

* TODO


# Requirements

* TODO


# Installation

You can install "mewbot-io-rss" via [pip](https://pypi.org/project/pip/) from [PyPI](https://pypi.org/project)
```shell
$ pip install mewbot-io-rss
```


# Usage


* TODO

# Contributing

Contributions are very welcome.
Tests can be run using [Mewbot dev tools](https://github.com/mewbotorg/mewbot-dev-tools).
These can be installed via
```shell
$ pip install mewbot-dev-tools
```
Then cd into the root of this repo and run
```shell
$ mewbot-test
```
Please ensure the coverage at least stays the same before you submit a pull request.

# License

Distributed under the terms of the MIT license.
"mewbot-io-rss" is free and open source software


# Issues

If you encounter any problems, please [file an issue](https://github.com/mewbotorg/mewbot-io-rss/issues) along with a detailed description.

# Features

Likewise, please [raise an issue](https://github.com/mewbotorg/mewbot-io-rss/issues) if there's a feature you want.

# Helpful links

 - [MIT license](http://opensource.org/licenses/MIT)
 - [BSD-3 license](http://opensource.org/licenses/BSD-3-Clause)
 - [GNU GPL v3.0](http://www.gnu.org/licenses/gpl-3.0.txt)
 - [Apache Software License 2.0](http://www.apache.org/licenses/LICENSE-2.0)

